<?php
/**
 * Wordpress Plugin "Top Spammers" ({@link http://ten-fingers-and-a-brain.com/wordpress-plugins/top-spammers/ Plugin Homepage})
 * admin-page template file
 *
 * Top Spammers displays a list of your top spammers' IP addresses, based on all comments in your database that are marked as spam.
 * It also generates a blacklist for your .htaccess file to block those spammers from your website entirely, thus taking load off the server.
 *  You will need another plugin (like {@link http://akismet.com/ Akismet}) to identify the spam.
 *
 * @package TopSpammers
 * @category tfnabWordpressPlugins
 * @version 0.4 / SVN: $Id: top-spammers-template.php 31 2009-09-15 14:55:20Z martin $
 * @since 0.4
 * @author Martin Lormes {@link http://ten-fingers-and-a-brain.com/}
 */
?>
<div class="wrap">
  <h2><?php _e ( 'Top Spammers' , 'top-spammers' ); ?></h2>
  <?php if ( empty ( $ips ) AND empty ( $blacklist ) ) : ?>
    <p><?php _e ( 'Lucky you: no spam.' , 'top-spammers' ); ?></p>
  <?php else : ?>
    <p><?php _e ( 'These are your top spammers\' IP addresses.' , 'top-spammers' ); ?></p>
    <div id="col-container">
      
      <div id="col-right">
        <h3><?php printf ( __ ( 'The top %d' , 'top-spammers' ), $display_top ); ?></h3>
        <?php if ( empty ( $ips ) ) : ?>
          <p><?php _e ( 'Lucky you: no new spam.' , 'top-spammers' ); ?></p>
        <?php else : ?>
          <form id="top-spammers-form" action="" method="post">
            <?php wp_nonce_field ( 'top-spammers-purge-spam' ); ?>
            <input type="hidden" name="action" value="top-spammers-purge-spam" />
            <div class="tablenav">
              <div class="alignleft actions">
                <input type="submit" value="<?php _e ( 'Delete spam comments from selected ip addresses, and add ip addresses to blacklist' , 'top-spammers' ); ?>" class="button-secondary" />
              </div>
            </div>
            <div class="clear"></div>
            <table class="widefat fixed">
              <thead>
                <tr>
                  <th scope="col" id="cb" class="manage-column column-cb check-column" style=""><input type="checkbox"></th>
                  <th scope="col" id="ip" class="manage-column"><?php _e ( 'IP address' , 'top-spammers' ); ?></th>
                  <th scope="col" id="hostname" class="manage-column"><?php _e ( 'Host name' , 'top-spammers' ); ?></th>
                  <th scope="col" id="count" class="manage-column num"><?php _e ( 'count' , 'top-spammers' ); ?></th>
                </tr>
              </thead>
              <tfoot>
                <tr>
                  <th scope="col" class="manage-column column-cb check-column" style=""><input type="checkbox"></th>
                  <th scope="col" class="manage-column"><?php _e ( 'IP address' , 'top-spammers' ); ?></th>
                  <th scope="col" class="manage-column"><?php _e ( 'Host name' , 'top-spammers' ); ?></th>
                  <th scope="col" class="manage-column num"><?php _e ( 'count' , 'top-spammers' ); ?></th>
                </tr>
              </tfoot>
              <tbody>
                <?php foreach ( array_slice ( $ips, 0, $display_top ) as $ip ) : ?>
                  <tr>
                    <th scope="row" class="check-column"><input name="delete_ip[]" value="<?php echo $ip['ip']; ?>" type="checkbox"></th>
                    <td><?php echo $ip['ip']; ?></td>
                    <td><?php if ( $display_treshold_ptr <= $ip['count'] ) echo gethostbyaddr ( $ip['ip'] ); ?></td>
                    <td><?php echo $ip['count']; ?></td>
                  </tr>
                <?php endforeach; ?>
              </tbody>
            </table>
            <div class="tablenav">
              <div class="alignleft actions">
                <input type="submit" value="<?php _e ( 'Delete spam comments from selected ip addresses, and add ip addresses to blacklist' , 'top-spammers' ); ?>" class="button-secondary" />
              </div>
            </div>
          </form>
          <script type="text/javascript">
            //<![CDATA[
            document.getElementById('top-spammers-form').onsubmit=function(){return confirm('<?php _e ( 'You are about to delete spam comments from the selected ip addresses.\\n\\\'Cancel\\\' to stop, \\\'OK\\\' to delete.' , 'top-spammers' ); ?>');};
            //]]>
          </script>
        <?php endif; ?>
      </div>
      
      <div id="col-left">
        <h3><?php _e ( 'Your blacklist (rules for your .htaccess)' , 'top-spammers' ); ?></h3>
        <?php if ( empty ( $blacklist ) ) : ?>
          <p><?php _e ( 'You haven\'t blacklisted anyone, yet.' , 'top-spammers' ); ?></p>
        <?php else : ?>
          <form><p><textarea rows="15" class="large-text readonly" name="rules" id="rules" readonly="readonly"><?php
            echo "## BEGIN Top Spammers\n";
            foreach ( $blacklist as $ip ) echo "deny from $ip\n";
            echo "## END Top Spammers\n";
          ?></textarea></p></form>
          <div class="form-wrap">
            <p><?php _e ( '<strong>Instructions:</strong> copy these lines to your .htaccess-file and those IP addresses will be blocked from accessing your site entirely, probably taking some load off your server. As of now you\'re going to have to do this manually, sorry about that.' , 'top-spammers' ); ?></p>
          </div>
          <form id="top-spammers-reset-form" action="" method="post">
            <?php wp_nonce_field ( 'top-spammers-reset-blacklist' ); ?>
            <input type="hidden" name="action" value="top-spammers-reset-blacklist" />
            <input type="submit" value="<?php _e ( 'Reset blacklist (delete all ip addresses)' , 'top-spammers' ); ?>" class="button-secondary" />
          </form>
          <script type="text/javascript">
            //<![CDATA[
            document.getElementById('top-spammers-reset-form').onsubmit=function(){return confirm('<?php _e ( 'You are about to reset your blacklist.\\n\\\'Cancel\\\' to stop, \\\'OK\\\' to reset.' , 'top-spammers' ); ?>');};
            //]]>
          </script>
        <?php endif; ?>
      </div>
      
    </div>
  <?php endif; ?>
  <p class="clear"></p>
</div>
