<?php
/**
 * Wordpress Plugin "Top Spammers" ({@link http://ten-fingers-and-a-brain.com/wordpress-plugins/top-spammers/ Plugin Homepage})
 * class file (the WP-version)
 *
 * Top Spammers displays a list of your top spammers' IP addresses, based on all comments in your database that are marked as spam.
 * It also generates a blacklist for your .htaccess file to block those spammers from your website entirely, thus taking load off the server.
 *  You will need another plugin (like {@link http://akismet.com/ Akismet}) to identify the spam.
 *
 * @package TopSpammers
 * @subpackage WP
 * @category tfnabWordpressPlugins
 * @version 0.4 / SVN: $Id: top-spammers-wp.php 31 2009-09-15 14:55:20Z martin $
 * @since 0.4
 * @author Martin Lormes {@link http://ten-fingers-and-a-brain.com/}
 */
/**
 * Wordpress Plugin "Top Spammers" ({@link http://ten-fingers-and-a-brain.com/wordpress-plugins/top-spammers/ Plugin Homepage})
 *  this class is merely a wrapper for the plugin's (static) functions (the WP-version)
 *
 * Top Spammers displays a list of your top spammers' IP addresses, based on all comments in your database that are marked as spam.
 * It also generates a blacklist for your .htaccess file to block those spammers from your website entirely, thus taking load off the server.
 *  You will need another plugin (like {@link http://akismet.com/ Akismet}) to identify the spam.
 *
 * @package TopSpammers
 * @subpackage WP
 * @category tfnabWordpressPlugins
 * @version 0.4 / SVN: $Id: top-spammers-wp.php 31 2009-09-15 14:55:20Z martin $
 * @author Martin Lormes {@link http://ten-fingers-and-a-brain.com/}
 *
 * @todo allow the user to sort the list by ip address rather than the default which is by count
 * @todo users need to be able to remove a single address from the blacklist
 * @todo prevent the user from blocking themselves by not allowing them to blacklist their own/current ip address ($_SERVER['REMOTE_ADDR'])
 * @todo display a warning when an ip address on the list also has approved comments
 * @todo actually write to .htaccess
 * @todo block entire subnets
 */
class pluginTopSpammers
{
  /** loads the plugin */
  static function init ()
  {
    // i18n/l10n
    load_plugin_textdomain ( 'top-spammers', '', basename ( dirname ( __FILE__ ) ) );
    
    // add plugin page to admin menu
    add_action ( 'admin_menu', array ( __CLASS__, 'add_admin_menu_page' ) );
  }
  
  /** adds plugin page to admin menu; put it right underneath 'Dashboard' */
  static function add_admin_menu_page ()
  {
    add_submenu_page ( 'index.php', __ ( 'Top Spammers', 'top-spammers' ), __ ( 'Top Spammers', 'top-spammers' ), 'edit_files', 'top-spammers', array ( __CLASS__, 'admin_menu_page' ) );
  }
  
  /** the plugin page and all the actual code  old php style spaghetti code */
  static function admin_menu_page ()
  {
    // make $wpdb available in the method context
    global $wpdb;
    
    // get blacklist, initialize to empty array
    $blacklist = get_option ( 'top-spammers_blacklist' );
    if ( empty ( $blacklist ) ) $blacklist = array ();
    
    // check blacklist 'format'
    $blacklist_version = get_option ( 'top-spammers_version' );
    if ( !$blacklist_version OR TOP_SPAMMERS_VERSION != $blacklist_version ) // blacklist needs an update
    {
      delete_option ( 'top-spammers_blacklist' );
      add_option ( 'top-spammers_blacklist', $blacklist, '', 'no' );
      update_option ( 'top-spammers_version', TOP_SPAMMERS_VERSION );
    }
    
    // user action: reset blacklist
    if ( isset ( $_POST['action'] ) AND 'top-spammers-reset-blacklist' == $_POST['action'] )
    {
      check_admin_referer ( 'top-spammers-reset-blacklist' );
      $blacklist = array ();
      update_option ( 'top-spammers_blacklist', $blacklist );
    }
    
    // user action: purge spam
    if ( isset ( $_POST['action'] ) AND 'top-spammers-purge-spam' == $_POST['action'] AND isset ( $_POST['delete_ip'] ) )
    {
      check_admin_referer ( 'top-spammers-purge-spam' );
      
      // merge blacklist and selected ip addresses
      $blacklist = array_unique ( array_merge ( $blacklist, $_POST['delete_ip'] ) );
      natsort ( $blacklist );
      update_option ( 'top-spammers_blacklist', $blacklist );
      
      // actually purge spam originating from selected ip addresses
      $deletelist = '("' . implode ( '","', $_POST['delete_ip'] ) . '")';
      $deleteqry = "DELETE FROM $wpdb->comments WHERE comment_approved = 'spam' AND comment_author_IP IN $deletelist";
      $num_deleted = $wpdb->query ( $deleteqry );
      
      echo '<div id="message" class="updated fade"><p><strong>' . sprintf ( __ ( '%d spam deleted' , 'top-spammers' ), $num_deleted ) . '</strong></p></div>';
      
    }
    
    // get all spammers' ip addresses, count them, order: top spammers first; as an assoc array
    $qry = "SELECT comment_author_IP AS ip, COUNT(*) AS count FROM $wpdb->comments WHERE comment_approved = 'spam' GROUP BY ip ORDER BY count DESC";
    $ips = $wpdb->get_results ( $qry, ARRAY_A );
    
    // some display settings
    // these will eventually be configurable and stored in wp_options
    $display_top = 50; // don't show all spammers, only the top x
    $display_treshold_ptr = 5; // lookup the hostname only if there are x (or more) spam comments from that ip
    
    // load admin-page template file
    include ( dirname ( __FILE__ ) . '/top-spammers-template.php' );
  }
}
